/*!  ==========================================================================
  Xceed DataGrid for JavaScript (Angular) - DISTRIBUTION CODE
  Version 1.7.0
  Copyright (c) 2020-present, Xceed Software Inc.

  This file is part of the Xceed DataGrid for JavaScript (Angular) product. The use and
  distribution of this Distribution Code is subject to the terms
  and conditions referring to "Distribution Code" that are specified in
  the XCEED SOFTWARE LICENSE AGREEMENT accompanying this product.
  Please see Licenses.pdf for a complete description.
============================================================================ */
import { EventEmitter, Component, ViewChild, Input, Output, NgModule, ɵɵdefineInjectable, Injectable } from '@angular/core';
import { DataGrid } from 'xceed-datagrid';

class DataGridComponent {
    constructor() {
        this.columnChanged = new EventEmitter();
        this.filterChanged = new EventEmitter();
        this.groupChanged = new EventEmitter();
        this.sortChanging = new EventEmitter();
        this.sortChanged = new EventEmitter();
        this.selectionChanged = new EventEmitter();
    }
    ngAfterViewInit() {
        const dataGrid = new DataGrid(this.container.nativeElement, this.options);
        dataGrid.setOptions({
            dataSource: this.dataSource,
            columnDefinitions: this.columnDefinitions,
            experimental: this.experimental,
            filterDefinitions: this.filterDefinitions,
            filterOptions: this.filterOptions,
            groupConfigurations: this.groupConfigurations,
            groupDefinitions: this.groupDefinitions,
            sortConfigurations: this.sortConfigurations,
            sortDefinitions: this.sortDefinitions
        });
        dataGrid.addEventListener("columnChanged", this.onColumnChanged.bind(this));
        dataGrid.addEventListener("filterChanged", this.onFilterChanged.bind(this));
        dataGrid.addEventListener("groupChanged", this.onGroupChanged.bind(this));
        dataGrid.addEventListener("sortChanging", this.onSortChanging.bind(this));
        dataGrid.addEventListener("sortChanged", this.onSortChanged.bind(this));
        dataGrid.addEventListener("selectionChanged", this.onSelectionChanged.bind(this));
        this.dataGrid = dataGrid;
    }
    ngOnChanges(changes) {
        if (!this.dataGrid)
            return;
        //# Bug 1041: We would like to replace the any type with PartialDataGridOptions.
        //#           However, the compiler complains about the type from the declaration files.  
        const options = {};
        for (const propName in changes) {
            if (!changes.hasOwnProperty(propName)) {
                continue;
            }
            const change = changes[propName];
            switch (propName) {
                case "dataSource":
                    {
                        options.dataSource = change.currentValue;
                    }
                    break;
                case "columnDefinitions":
                    {
                        options.columnDefinitions = change.currentValue;
                    }
                    break;
                case "experimental":
                    {
                        options.experimental = change.currentValue;
                    }
                    break;
                case "filterDefinitions":
                    {
                        options.filterDefinitions = change.currentValue;
                    }
                    break;
                case "filterOptions":
                    {
                        options.filterOptions = change.currentValue;
                    }
                    break;
                case "groupConfigurations":
                    {
                        options.groupConfigurations = change.currentValue;
                    }
                    break;
                case "groupDefinitions":
                    {
                        options.groupDefinitions = change.currentValue;
                    }
                    break;
                case "sortConfigurations":
                    {
                        options.sortConfigurations = change.currentValue;
                    }
                    break;
                case "sortDefinitions":
                    {
                        options.sortDefinitions = change.currentValue;
                    }
                    break;
                case "options":
                    {
                        this.dataGrid.setOptions(change.currentValue);
                    }
                    break;
                default:
                    break;
            }
        }
        this.dataGrid.setOptions(options);
    }
    onColumnChanged(eventArgs) {
        this.columnChanged.emit(eventArgs);
    }
    onFilterChanged(eventArgs) {
        this.filterChanged.emit(eventArgs);
    }
    onGroupChanged(eventArgs) {
        this.groupChanged.emit(eventArgs);
    }
    onSortChanging(eventArgs) {
        this.sortChanging.emit(eventArgs);
    }
    onSortChanged(eventArgs) {
        this.sortChanged.emit(eventArgs);
    }
    onSelectionChanged(eventArgs) {
        this.selectionChanged.emit(eventArgs);
    }
}
DataGridComponent.decorators = [
    { type: Component, args: [{
                selector: "xceed-datagrid",
                template: `
    <div style="display: flex; flex-flow: column; height: 100%;">
      <div #container style="display: flex; flex-flow: column; flex: 1 1 auto; min-height: 0;"></div>
    </div>
  `
            },] }
];
DataGridComponent.ctorParameters = () => [];
DataGridComponent.propDecorators = {
    container: [{ type: ViewChild, args: ["container",] }],
    dataSource: [{ type: Input }],
    columnDefinitions: [{ type: Input }],
    experimental: [{ type: Input }],
    filterDefinitions: [{ type: Input }],
    filterOptions: [{ type: Input }],
    groupConfigurations: [{ type: Input }],
    groupDefinitions: [{ type: Input }],
    sortConfigurations: [{ type: Input }],
    sortDefinitions: [{ type: Input }],
    options: [{ type: Input }],
    columnChanged: [{ type: Output }],
    filterChanged: [{ type: Output }],
    groupChanged: [{ type: Output }],
    sortChanging: [{ type: Output }],
    sortChanged: [{ type: Output }],
    selectionChanged: [{ type: Output }]
};

class DataGridModule {
}
DataGridModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DataGridComponent],
                imports: [],
                exports: [DataGridComponent],
            },] }
];

class DataGridService {
    constructor() { }
}
DataGridService.ɵprov = ɵɵdefineInjectable({ factory: function DataGridService_Factory() { return new DataGridService(); }, token: DataGridService, providedIn: "root" });
DataGridService.decorators = [
    { type: Injectable, args: [{
                providedIn: "root",
            },] }
];
DataGridService.ctorParameters = () => [];

/*
 * Public API Surface of datagrid-angular
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DataGridComponent, DataGridModule, DataGridService };
//# sourceMappingURL=xceed-datagrid-angular.js.map
